@@ -16,7 +16,7 @@
 # under the License.
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Sequence
+from typing import TYPE_CHECKING, Any, Callable, Sequence
 
 from azure.core.exceptions import ResourceNotFoundError
 
@@ -26,13 +26,17 @@ from airflow.providers.microsoft.azure.hooks.asb import AdminClientHook, Message
 if TYPE_CHECKING:
     import datetime
 
+    from azure.servicebus import ServiceBusMessage
     from azure.servicebus.management._models import AuthorizationRule
 
     from airflow.utils.context import Context
 
+    MessageCallback = Callable[[ServiceBusMessage], None]
+
 
 class AzureServiceBusCreateQueueOperator(BaseOperator):
-    """Create a Azure Service Bus queue under a Service Bus Namespace.
+    """
+    Create a Azure Service Bus queue under a Service Bus Namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -84,7 +88,8 @@ class AzureServiceBusCreateQueueOperator(BaseOperator):
 
 
 class AzureServiceBusSendMessageOperator(BaseOperator):
-    """Send Message or batch message to the Service Bus queue.
+    """
+    Send Message or batch message to the Service Bus queue.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -126,7 +131,8 @@ class AzureServiceBusSendMessageOperator(BaseOperator):
 
 
 class AzureServiceBusReceiveMessageOperator(BaseOperator):
-    """Receive a batch of messages at once in a specified Queue name.
+    """
+    Receive a batch of messages at once in a specified Queue name.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -137,6 +143,9 @@ class AzureServiceBusReceiveMessageOperator(BaseOperator):
     :param max_wait_time: Maximum time to wait in seconds for the first message to arrive.
     :param azure_service_bus_conn_id: Reference to the
         :ref: `Azure Service Bus connection <howto/connection:azure_service_bus>`.
+    :param message_callback: Optional callback to process each message. If not provided, then
+        the message will be logged and completed. If provided, and throws an exception, the
+        message will be abandoned for future redelivery.
     """
 
     template_fields: Sequence[str] = ("queue_name",)
@@ -149,6 +158,7 @@ class AzureServiceBusReceiveMessageOperator(BaseOperator):
         azure_service_bus_conn_id: str = "azure_service_bus_default",
         max_message_count: int = 10,
         max_wait_time: float = 5,
+        message_callback: MessageCallback | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -156,6 +166,7 @@ class AzureServiceBusReceiveMessageOperator(BaseOperator):
         self.azure_service_bus_conn_id = azure_service_bus_conn_id
         self.max_message_count = max_message_count
         self.max_wait_time = max_wait_time
+        self.message_callback = message_callback
 
     def execute(self, context: Context) -> None:
         """Receive Message in specific queue in Service Bus namespace by connecting to Service Bus client."""
@@ -164,12 +175,16 @@ class AzureServiceBusReceiveMessageOperator(BaseOperator):
 
         # Receive message
         hook.receive_message(
-            self.queue_name, max_message_count=self.max_message_count, max_wait_time=self.max_wait_time
+            self.queue_name,
+            max_message_count=self.max_message_count,
+            max_wait_time=self.max_wait_time,
+            message_callback=self.message_callback,
         )
 
 
 class AzureServiceBusDeleteQueueOperator(BaseOperator):
-    """Delete the Queue in the Azure Service Bus namespace.
+    """
+    Delete the Queue in the Azure Service Bus namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -204,7 +219,8 @@ class AzureServiceBusDeleteQueueOperator(BaseOperator):
 
 
 class AzureServiceBusTopicCreateOperator(BaseOperator):
-    """Create an Azure Service Bus Topic under a Service Bus Namespace.
+    """
+    Create an Azure Service Bus Topic under a Service Bus Namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -325,7 +341,8 @@ class AzureServiceBusTopicCreateOperator(BaseOperator):
 
 
 class AzureServiceBusSubscriptionCreateOperator(BaseOperator):
-    """Create an Azure Service Bus Topic Subscription under a Service Bus Namespace.
+    """
+    Create an Azure Service Bus Topic Subscription under a Service Bus Namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -431,7 +448,8 @@ class AzureServiceBusSubscriptionCreateOperator(BaseOperator):
 
 
 class AzureServiceBusUpdateSubscriptionOperator(BaseOperator):
-    """Update an Azure ServiceBus Topic Subscription under a ServiceBus Namespace.
+    """
+    Update an Azure ServiceBus Topic Subscription under a ServiceBus Namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -490,7 +508,8 @@ class AzureServiceBusUpdateSubscriptionOperator(BaseOperator):
 
 
 class ASBReceiveSubscriptionMessageOperator(BaseOperator):
-    """Receive a Batch messages from a Service Bus Subscription under specific Topic.
+    """
+    Receive a Batch messages from a Service Bus Subscription under specific Topic.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -507,6 +526,9 @@ class ASBReceiveSubscriptionMessageOperator(BaseOperator):
         an empty list will be returned.
     :param azure_service_bus_conn_id: Reference to the
         :ref:`Azure Service Bus connection <howto/connection:azure_service_bus>`.
+    :param message_callback: Optional callback to process each message. If not provided, then
+        the message will be logged and completed. If provided, and throws an exception, the
+        message will be abandoned for future redelivery.
     """
 
     template_fields: Sequence[str] = ("topic_name", "subscription_name")
@@ -520,6 +542,7 @@ class ASBReceiveSubscriptionMessageOperator(BaseOperator):
         max_message_count: int | None = 1,
         max_wait_time: float | None = 5,
         azure_service_bus_conn_id: str = "azure_service_bus_default",
+        message_callback: MessageCallback | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -528,6 +551,7 @@ class ASBReceiveSubscriptionMessageOperator(BaseOperator):
         self.max_message_count = max_message_count
         self.max_wait_time = max_wait_time
         self.azure_service_bus_conn_id = azure_service_bus_conn_id
+        self.message_callback = message_callback
 
     def execute(self, context: Context) -> None:
         """Receive Message in specific queue in Service Bus namespace by connecting to Service Bus client."""
@@ -536,12 +560,17 @@ class ASBReceiveSubscriptionMessageOperator(BaseOperator):
 
         # Receive message
         hook.receive_subscription_message(
-            self.topic_name, self.subscription_name, self.max_message_count, self.max_wait_time
+            self.topic_name,
+            self.subscription_name,
+            self.max_message_count,
+            self.max_wait_time,
+            message_callback=self.message_callback,
         )
 
 
 class AzureServiceBusSubscriptionDeleteOperator(BaseOperator):
-    """Delete the topic subscription in the Azure ServiceBus namespace.
+    """
+    Delete the topic subscription in the Azure ServiceBus namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -579,7 +608,8 @@ class AzureServiceBusSubscriptionDeleteOperator(BaseOperator):
 
 
 class AzureServiceBusTopicDeleteOperator(BaseOperator):
-    """Delete the topic in the Azure Service Bus namespace.
+    """
+    Delete the topic in the Azure Service Bus namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
